@@ -4,6 +4,8 @@ function(input){
 #produces X vector according to lengths, assigning values to left endpoints of 
 #interval lengths, according to a given startpoint.
 
+X<-NULL
+
 startpoint<-input[1];
 lengths<-input[2:length(input)];
 
@@ -13,14 +15,9 @@ if (is.na(startpoint)){
 startpoint<-sum(lengths)/(n+1);
 		}
 
-
-X<-matrix(0,1,n+1);
-
 X[1]<-startpoint;
 
-for (i in 1:n){
-	X[i+1]<-X[i]+lengths[i];
-	}
+X<-matrix(c(X[1],X[1]+cumsum(lengths)),nrow=1)
 
 lengths[n+1]<-sum(lengths)/(n+1);
 
